ytree\.tree\_farm\.ancestry\_short\.add\_ancestry\_short
========================================================

.. currentmodule:: ytree.tree_farm.ancestry_short

.. autofunction:: add_ancestry_short